package com.foreverwin.mesnac.common.mapper;

import com.foreverwin.mesnac.common.model.CustomReportMainmodel;
import com.foreverwin.mesnac.common.model.CustomReportSearchConditionConfig;
import com.foreverwin.mesnac.common.model.CustomReportSearchConditionDynSQLConfig;
import com.foreverwin.mesnac.common.model.CustomReportSearchResultColumnConfig;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

@Repository
public interface CustomReportConfigMapper {

    List<CustomReportMainmodel> selectReportIdDialog(String site);

    List<CustomReportMainmodel> selectMain(@Param("site") String site, @Param("reportId") String reportId);

    List<CustomReportSearchConditionConfig> selectSearchConditionConfig(String mainhandle);

    List<CustomReportSearchConditionDynSQLConfig> selectDynSqlConfig(String mainhandle);

    List<CustomReportSearchResultColumnConfig> selectResultColumnConfig(String mainhandle);

    int deleteDynSqlConfig(String mainhandle);

    int deleteResultColumnConfig(String mainhandle);

    int deleteSearchConditionConfig(String mainhandle);

    int deleteMainmodel(String mainhandle);

    int insertDynSqlConfig(CustomReportSearchConditionDynSQLConfig customReportSearchConditionDynSQLConfig);

    int insertResultColumnConfig(CustomReportSearchResultColumnConfig customReportSearchResultColumnConfig);

    int insertSearchConditionConfig(CustomReportSearchConditionConfig customReportSearchConditionConfig);

    int insertInsertMainmodel(CustomReportMainmodel customReportMainmodel);
}
